Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeProof ¶
MakeProof derives the pubkey from seckey and returns a Schnorr signature over the proof message as a hex-encoded string.
func ProofMessage ¶
ProofMessage returns the message that should be signed by the secret key to prove the compromise of the given pubkey.
Types ¶
type Confirmed ¶
type Confirmed struct {
DetectedAt *int64 `json:"detected_at,omitempty"`
Proof string `json:"proof"`
}
Confirmed is a compromise result backed by a cryptographic proof. The proof is a Schnorr signature over "this-key-was-compromised-<pubkey>", produced with the compromised private key. Call [Confirmed.Verify] to check it.
func (Confirmed) MarshalJSON ¶
type Result ¶
type Result interface {
// contains filtered or unexported methods
}
Result is the interface implemented by all compromise results. A Result is either a Confirmed or a Suspected value.
Click to show internal directories.
Click to hide internal directories.